<template>
    <Head title="Major"/>
    <AdminMainLayout>
        <div class="card">
            <div class="card-body">
                <div class="card-title">
                    <div class="d-flex justify-content-between align-items-center">
                        <h4>Tambah Lowongan Pekerjaan</h4>
                    </div>
                </div>
                <div class="container">
                    <form @submit.prevent="submit">
                        <div class="row justify-content-center">
                            <div class="col">
                                <BaseInput
                                    v-model="form.title"
                                    label="Nama Lowongan"
                                    placeholder="Nama Lowongan"
                                    class="mb-3"
                                    :error-message="form.errors.title"
                                />
                                <BaseDropDown
                                    v-model="form.type"
                                    label="Tipe Pekerjaan"
                                    placeholder="-- Pilih Tipe Pekerjaan --"
                                    :error-message="form.errors.type"
                                    :options="[
                                {label: 'Full Time', value: 'full-time'},
                                {label: 'Part Time', value: 'part-time'},
                                {label: 'Internship', value: 'internship'},
                                {label: 'Freelance', value: 'freelance'},
                            ]"
                                    class="mb-3"
                                />
                                <BaseInput
                                    v-model="form.location"
                                    label="Lokasi"
                                    placeholder="Lokasi"
                                    class="mb-3"
                                    :error-message="form.errors.location"
                                />
                                <BaseInput
                                    v-model="form.apply_link"
                                    label="Link Lamar"
                                    placeholder="Link Lamar"
                                    class="mb-3"
                                    :disabled="form.is_easy_apply"
                                    :error-message="form.errors.apply_link"
                                />
                            </div>
                            <div class="col">
                                <BaseDropDown
                                    v-model="form.company_id"
                                    label="Mitra"
                                    placeholder="-- Pilih Mitra --"
                                    :error-message="form.errors.company_id"
                                    :options="company.map(item => ({label: item.name, value: item.id}))"
                                    class="mb-3"
                                />
                                <BaseInputFile
                                    v-model="form.poster"
                                    label="Poster"
                                    class="mb-3"
                                    :error-message="form.errors.poster"
                                />
                                <BaseInput
                                    v-model="form.deadline"
                                    label="Deadline"
                                    type="date"
                                    class="mb-3"
                                    :error-message="form.errors.deadline"
                                />
                                <div class="d-flex gap-5">
                                    <BaseSwitch
                                        v-model="form.is_easy_apply"
                                        label="Lamar Mudah"
                                        class="mb-3"
                                    />
                                    <BaseSwitch
                                        v-model="form.is_active"
                                        label="Aktif"
                                        class="mb-3"
                                    />
                                </div>
                            </div>
                        </div>
                        <div class="form-group mb-4">
                            <label class="form-label">Deskripsi Pekerjaan</label>
                            <QuillEditor
                                v-model:content="form.description"
                                label="Deskripsi"
                                content-type="html"
                            />
                            <span v-if="form.errors.description" class="text-danger">{{ form.errors.description }}</span>
                        </div>
                        <div class="form-group mb-4">
                            <label class="form-label">Kualifikasi</label>
                            <QuillEditor
                                v-model:content="form.qualification"
                                label="Kualifikasi"
                                content-type="html"
                            />
                            <span v-if="form.errors.qualification" class="text-danger">{{ form.errors.qualification }}</span>
                        </div>
                        <div class="form-group mb-4">
                            <label class="form-label">Benefit</label>
                            <QuillEditor
                                v-model:content="form.benefits"
                                label="Benefit"
                                content-type="html"
                            />
                            <span v-if="form.errors.benefits" class="text-danger">{{ form.errors.benefits }}</span>
                        </div>
                        <BaseButton
                            class="btn-primary mt-4"
                            type="submit"
                        >
                            Simpan Data
                        </BaseButton>
                    </form>
                </div>
            </div>
        </div>
    </AdminMainLayout>
</template>
<script setup>
import {Head, Link, useForm} from '@inertiajs/vue3';
import AdminMainLayout from "@/Layouts/AdminMainLayout.vue";
import BaseButton from "@/Components/Button/BaseButton.vue";
import BaseInput from "@/Components/Forms/BaseInput.vue";
import BaseDropDown from "@/Components/Forms/BaseDropDown.vue";
import {QuillEditor} from "@vueup/vue-quill";
import BaseInputFile from "@/Components/Forms/BaseInputFile.vue";
import BaseSwitch from "@/Components/Forms/BaseSwitch.vue";
import {watch} from "vue";

defineProps({
    company: {
        type: Array
    }
})


const form = useForm({
    company_id: '',
    title: '',
    description: '',
    qualification: '',
    benefits: '',
    type: '',
    poster: null,
    location: '',
    is_easy_apply: false,
    apply_link: '',
    deadline: '',
    is_active: true,
})

const submit = () => {
    console.log(form);
    form.post('/backoffice/admin/vacancy', {
        preserveScroll: true,
        forceFormData: true,
        onSuccess: () => {
            form.reset();
        }
    });
}

watch(form.is_easy_apply, (value) => {
    if (value) {
        form.apply_link = '';
    }
})
</script>
